import sys
import iotbx.pdb
from libtbx.utils import null_out
from mmtbx import map_tools
from mmtbx.maps import fem
import mmtbx.utils
  
def run(args):
  inputs = mmtbx.utils.process_command_line_args(args = args)
  df = mmtbx.utils.determine_data_and_flags(
    reflection_file_server  = inputs.get_reflection_file_server(),
    log = null_out())
  pdb_inp = iotbx.pdb.input(file_name=inputs.pdb_file_names[0])
  xrs = pdb_inp.xray_structure_simple()
  #########
  f_obs = df.f_obs.average_bijvoet_mates()
  f_obs, r_free_flags = f_obs.common_sets(df.r_free_flags)
  fmodel = mmtbx.f_model.manager(
    f_obs          = f_obs,
    r_free_flags   = r_free_flags,
    xray_structure = xrs)
  fmodel.update_all_scales()
  print fmodel.r_work(), fmodel.r_free()
  fmodel.show()
  #
  mc = map_tools.electron_density_map(
    fmodel=fmodel).map_coefficients(
      map_type         = "2mFo-DFc",
      use_shelx_weight = False,
      isotropize       = True,
      fill_missing     = False)
  mc_sh = map_tools.electron_density_map(
    fmodel=fmodel).map_coefficients(
      map_type         = "2mFo-DFc",
      use_shelx_weight = True,
      shelx_weight_parameter = 1.5,
      isotropize       = True,
      fill_missing     = False)
  # 
  crystal_gridding = fmodel.f_obs().crystal_gridding(
    d_min              = fmodel.f_obs().d_min(),
    resolution_factor  = 0.25)
  fem.ccp4_map(cg=crystal_gridding, file_name="L107good_orig.ccp4", mc=mc)
  fem.ccp4_map(cg=crystal_gridding, file_name="L107good_shelx_w1.5.ccp4", mc=mc_sh)
  

if (__name__ == "__main__"):
  run(sys.argv[1:])

